rankeval\.dataset package
=========================

.. automodule:: rankeval.dataset
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

rankeval\.dataset\.dataset module
---------------------------------

.. automodule:: rankeval.dataset.dataset
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.dataset\.dataset\_container module
--------------------------------------------

.. automodule:: rankeval.dataset.dataset_container
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.dataset\.datasets\_fetcher module
-------------------------------------------

.. automodule:: rankeval.dataset.datasets_fetcher
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.dataset\.svmlight\_format module
------------------------------------------

.. automodule:: rankeval.dataset.svmlight_format
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.dataset\.write\_json\_dataset\_catalogue module
---------------------------------------------------------

.. automodule:: rankeval.dataset.write_json_dataset_catalogue
    :members:
    :undoc-members:
    :show-inheritance:


